@@ -461,7 +461,9 @@ $LANG08 = array(
     35 => ',       .',
     36 => 'Copy:',
     37 => 'Send me a copy of this email',
-    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
+    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:",
+    39 => 'Your last message was ',
+    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
 );
 
 ###############################################################################
@@ -1538,11 +1540,13 @@ $LANG_WHATSNEW = array(
     'days' => '',
     'weeks' => '',
     'months' => '',
+    'years' => 'years',
     'minute' => '',
     'hour' => '',
     'day' => '',
     'week' => '',
-    'month' => ''
+    'month' => '',
+    'year' => 'year'
 );
 
 ###############################################################################
